0.9.9 API documentation: vector_uint1_precision.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

vector_uint1_precision.hpp
Go to the documentation of this file.
1
11 #pragma once
12
13 #include "../detail/type_vec1.hpp"
14
15 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
16 # pragma message("GLM: GLM_EXT_vector_uint1_precision extension included")
17 #endif
18
19 namespace glm
20 {
23
27 typedef vec<1, unsigned int, highp> highp_uvec1;
28
32 typedef vec<1, unsigned int, mediump> mediump_uvec1;
33
37 typedef vec<1, unsigned int, lowp> lowp_uvec1;
38
40 }//namespace glm
glm::mediump_uvec1
vec< 1, unsigned int, mediump > mediump_uvec1
1 component vector of unsigned integer values.
Definition: vector_uint1_precision.hpp:32
glm::highp_uvec1
vec< 1, unsigned int, highp > highp_uvec1
1 component vector of unsigned integer values.
Definition: vector_uint1_precision.hpp:27
glm::lowp_uvec1
vec< 1, unsigned int, lowp > lowp_uvec1
1 component vector of unsigned integer values.
Definition: vector_uint1_precision.hpp:37
glm
Definition: common.hpp:20